//*** Stata 9 Dofile for "Who Said What? Message Source Cues Moderate Framing Effects"
// Questionnaire Version: 1 - 8, N=533
// Experiment 1: One-framed Information Flows
// ver = 1 (A, Liberal Source - Free Speech Frame)
// ver = 2 (B, Liberal Source - Public Order Frame)
// ver = 3 (C, Conservative Source - Free Speech Frame)
// ver = 4 (D, Conservative Sournce - Public Order Frame)
// Experiment 2: Two-framed Information Flows
// ver = 5 (E, Liberal Source - Free Speech Frame AND Conservative - Public Order Frame)
// ver = 6 (F, Conservative Source - Free Speech Frame AND Liberal Source - Public Order Frame)
// ver = 7 (G, Conservative Source - Public Order Frame AND Liberal Source - Free Speech Frame)
// ver = 8 (H, Liberal Source - Public Order Frame AND Conservative Source - Free Speech Frame) 

// Dofile for Stata 9
version 9

// Analysis for Experiment 1 ONLY
drop if ver>4

//*** INDEPENDENT VARIABLES
// [POFRAME] Frame -- Centered on Public Order, 1 = Free Speech, 0 = Public Order
gen poframe = 999
recode poframe (999=1) if ver==1 | ver==3
recode poframe (999=0) if ver==2 | ver==4
tab poframe
sum poframe
recode poframe (999=.)
sum poframe

// [FSFRAME] Frame -- Centered on Free Speech, 1 = Public Order, 0 = Free Speech
recode poframe (0=1)(1=0), gen(fsframe)
sum fsframe
tab fsframe poframe

// [CSOURCE] Source -- Centered on Conservative, 1 = Liberal, 0 = Conservative
gen csource = 999
recode csource (999=1) if ver==1 | ver==2
recode csource (999=0) if ver==3 | ver==4
tab csource 
sum csource
recode csource (999=.)
sum csource

// [LSOURCE] Source -- Centered on Liberal, 1 = Conservative, 0 = Liberal
recode csource (0=1)(1=0), gen(lsource)
sum lsource
tab csource lsource

// [THERM] Mean-Centered Con-Lib Thermometer, Higher #'s = More Conservative
gen th = (gaff2 - gaff1)/8
tab th
gen the = (th + 1)/2
tab the
egen theM = mean(the)
sum theM
gen therm = the - theM
sum therm, detail

// [THERML] Con-Lib Therm Centered at Min (Very Warm Toward Liberals)
tab the
gen thermL = the

// [THERMH] Con-Lib Therm Centered at Max (Very Warm Toward Conservatives)
tab the
gen thermH = the - 1
tab thermH

//*** DEPENDENT VARIABLES
// [VALUE1-3]: Value Importance 0 = Completely Unimportant, 1 = Extremely Important (7-point scale ranges from 0-1)
gen value1 = (val1-1)/6
gen value2 = (val2-1)/6
gen value3 = (val3-1)/6
sum value1-value3, det

// [DVRALLY]: Dependent Variable, Support for KKK Rally, 0 = Do NOT Support, 1 = Completely Support
tab rally
recode rally (1=9)(2=8)(3=7)(4=6)(5=5)(6=4)(7=3)(8=2)(9=1)
tab rally
gen dvrally = (rally-1)/8
sum dvrally
tab dvrally

// [DVTOL]: Dependent Varaible, General Tolerance Scale, 0 = Intolerant, 1 = Tolerant
recode tot2 (1=0)(2=1), gen (toler1) 
recode tot3 (1=0)(2=1), gen (toler2)
recode tot4 (1=0)(2=1), gen (toler3)
kr20 toler1 toler2 toler3

kr20 toler1 toler2 toler3 if ver<=4
//kr20 toler1 toler2 toler3 if ver>=5

gen tolerance = toler1 + toler2 + toler3
sum tolerance , det
gen dvtol = (tolerance)/3
sum dvtol, det

recode tot2 (1=1)(2=0), gen (toler4)
recode tot5 (1=1)(2=0)(3=.), gen (toler5)

msp toler1 toler2 toler3 toler4 toler5
kr20 toler1 toler2 toler3 toler4 toler5

//*** CONTROLS
recode sex (1=0)(2=1)(6=.)(8=.), gen(female)
tab female
recode race (1=1)(2=0)(3=0)(4=0)(5=0)(6=0)(8=.), gen(black)
recode race (1=0)(2=1)(3=0)(4=0)(5=0)(6=0)(8=.), gen(asian)
recode race (1=0)(2=0)(3=1)(4=0)(5=0)(6=0)(8=.), gen(hispanic)
recode race (1=0)(2=0)(3=0)(4=1)(5=0)(6=1)(8=.), gen(nonwhite)
tab black
tab asian
tab hispanic
tab nonwhite
recode pid (1=7)(2=6)(3=5)(5=3)(6=2)(7=1), gen(par)
gen part = (par - 1)/6
egen partM = mean(part)
gen party = part - partM
tab party


//*** INTERACTIONS
gen poXls = poframe*lsource
gen poXcs = poframe*csource
gen fsXls = fsframe*lsource
gen fsXcs = fsframe*csource
gen poXtherm = poframe*therm
gen fsXtherm = fsframe*therm
gen csXtherm = csource*therm
gen lsXtherm = lsource*therm
gen poXlsXtherm = poframe*csource*therm
gen poXcsXtherm = poframe*csource*therm
gen fsXlsXtherm = fsframe*lsource*therm
gen fsXcsXtherm = fsframe*csource*therm

gen poXthermL = poframe*thermL
gen fsXthermL = fsframe*thermL
gen csXthermL = csource*thermL
gen lsXthermL = lsource*thermL
gen poXlsXthermL = poframe*csource*thermL
gen poXcsXthermL = poframe*csource*thermL
gen fsXlsXthermL = fsframe*lsource*thermL
gen fsXcsXthermL = fsframe*csource*thermL

gen poXthermH = poframe*thermH
gen fsXthermH = fsframe*thermH
gen csXthermH = csource*thermH
gen lsXthermH = lsource*thermH
gen poXlsXthermH = poframe*csource*thermH
gen poXcsXthermH = poframe*csource*thermH
gen fsXlsXthermH = fsframe*lsource*thermH
gen fsXcsXthermH = fsframe*csource*thermH


//*** ANALYSES
// NOTE: Frame is the focal qualitative variable of interest.
// Message source is first-order moderator variable.
// The Con-Lib feeling thermometer is the second-order moderator variable.
// 2 x 2 x 2 on DVRALLY
reg dvrally fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party


//**2 X 2 Table: Frame X Source (AT MINIMUM LEVELS of Con-Lib Feeling Thermometer--Very Liberal)
// Reference categories = 0, intercepts provide means

// 2-way interaction: fsXls |   .3410146   .1773842     1.92   0.056    -.0083165    .6903456
// MATCH: FS X Lib Source
reg dvrally fsframe lsource thermL fsXls fsXthermL lsXthermL fsXlsXthermL female black asian hispanic nonwhite party
// Intercept:  _cons |   .4751585   .0941508     5.05   0.000     .2897428    .6605742

// FS X Con Source
reg dvrally fsframe csource thermL fsXcs fsXthermL csXthermL fsXcsXthermL female black asian hispanic nonwhite party
// Intercept: _cons |   .3607801    .099889     3.61   0.000     .1640639    .5574964

// MATCH: PO X Lib Source
reg dvrally poframe lsource thermL poXls poXthermL lsXthermL poXlsXthermL female black asian hispanic nonwhite party
// Intercept: _cons |     .20271   .1066887     1.90   0.059    -.0073972    .4128172

// PO X Con Source
reg dvrally poframe csource thermL poXcs poXthermL csXthermL poXcsXthermL female black asian hispanic nonwhite party
// Intercept: _cons |   .4293462   .1090272     3.94   0.000     .2146337    .6440587



//**2 X 2 Table: Frame X Source (AT MEAN LEVELS of Con-Lib Feeling Thermometer)
// 2-way interaction:  fsXls |  -.0385139   .0812447    -0.47   0.636     -.198513    .1214852
// FS X Lib Source
reg dvrally fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
// Intercept: _cons |   .4815562   .0481678    10.00   0.000     .3866971    .5764153
// FS X Con Source
reg dvrally fsframe csource therm fsXcs fsXtherm csXtherm fsXcsXtherm female black asian hispanic nonwhite party
// Intercept: _cons |   .5194397   .0494524    10.50   0.000     .4220507    .6168286
// PO X Lib
reg dvrally poframe lsource therm poXls poXtherm lsXtherm poXlsXtherm female black asian hispanic nonwhite party
// Intercept: _cons |   .3813555   .0508209     7.50   0.000     .2812715    .4814395
// PO X Con
reg dvrally poframe csource therm poXcs poXtherm csXtherm poXcsXtherm female black asian hispanic nonwhite party
// Intercept: _cons |   .3807251   .0513866     7.41   0.000      .279527    .4819232


//**2 X 2 Table: Frame X Source (AT MAXIMUM LEVELS of Con-Lib Feeling Thermometer--Very Conservative ID)
// 2-way Interaction: fsXls |  -.5995935   .2439921    -2.46   0.015    -1.080099   -.1190882

// FS X Lib Source:
reg dvrally fsframe lsource thermH fsXls fsXthermH lsXthermH fsXlsXthermH female black asian hispanic nonwhite party
// Intercept: _cons |   .4910142   .1400874     3.51   0.001     .2151335     .766895

// MATCH: FS X Con Source
reg dvrally fsframe csource thermH fsXcs fsXthermH csXthermH fsXcsXthermH female black asian hispanic nonwhite party
// Intercept:  _cons |   .7539955   .1249342     6.04   0.000     .5079567    1.000034

// PO X Lib
reg dvrally poframe lsource thermH poXls poXthermH lsXthermH poXlsXthermH female black asian hispanic nonwhite party
// Intercept:  _cons |   .6454578   .1394132     4.63   0.000     .3709048    .9200108

// MATCH: PO X Con
reg dvrally poframe csource thermH poXcs poXthermH csXthermH poXcsXthermH female black asian hispanic nonwhite party
// Intercept:  _cons |   .3088456    .140319     2.20   0.029     .0325086    .5851826


// Now rerun analyses with 7-point ideology measure instead
gen ideol = (ideo-1)/6
egen ideolM = mean(ideol)
gen ideology = ideol - ideolM
tab ideology
sum ideology

gen poXideo = poframe*ideology
gen fsXideo = fsframe*ideology
gen csXideo = csource*ideology
gen lsXideo = lsource*ideology
gen poXlsXideo = poframe*csource*ideology
gen poXcsXideo = poframe*csource*ideology
gen fsXlsXideo = fsframe*lsource*ideology
gen fsXcsXideo = fsframe*csource*ideology

gen ideologyL = ideol
gen poXideoL = poframe*ideologyL
gen fsXideoL = fsframe*ideologyL
gen csXideoL = csource*ideologyL
gen lsXideoL = lsource*ideologyL
gen poXlsXideoL = poframe*csource*ideologyL
gen poXcsXideoL = poframe*csource*ideologyL
gen fsXlsXideoL = fsframe*lsource*ideologyL
gen fsXcsXideoL = fsframe*csource*ideologyL

gen ideologyH = ideol-1
gen poXideoH = poframe*ideologyH
gen fsXideoH = fsframe*ideologyH
gen csXideoH = csource*ideologyH
gen lsXideoH = lsource*ideologyH
gen poXlsXideoH = poframe*csource*ideologyH
gen poXcsXideoH = poframe*csource*ideologyH
gen fsXlsXideoH = fsframe*lsource*ideologyH
gen fsXcsXideoH = fsframe*csource*ideologyH

// 2 x 2 x 2 on DVRALLY
reg dvrally fsframe lsource ideology fsXls fsXideo lsXideo fsXlsXideo female black asian hispanic nonwhite party


reg dvrally fsframe lsource ideologyL fsXls fsXideoL lsXideoL fsXlsXideoL female black asian hispanic nonwhite party
reg dvrally fsframe csource ideologyL fsXcs fsXideoL csXideoL fsXcsXideoL female black asian hispanic nonwhite party

reg dvrally fsframe csource ideologyH fsXcs fsXideoH csXideoL fsXcsXideoH female black asian hispanic nonwhite party
reg dvrally fsframe lsource ideologyH fsXls fsXideoH lsXideoH fsXlsXideoH female black asian hispanic nonwhite party


// 2 x 2 x 2 on DVTOL Con-Lib Therm
tab therm
ologit dvtol fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party

estsimp ologit dvtol fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party


// Match Conditions
// Liberal ID / Liberal Source / FS Frame
setx (therm)-.4034927 (fsframe lsource fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// Liberal ID / Liberal Source / PO Frame
setx (therm)-.4034927 (fsframe)1 (fsXtherm)-.4034927 (lsource fsXls lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// Conservative ID / Conservative Source /FS Frame
setx (therm).5965073 (lsource)1 (lsXtherm).5965073 (fsframe fsXls fsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// Conservative ID / Conservative Source /PO Frame
setx (therm).5965073 (fsframe lsource fsXls)1 (fsXtherm lsXtherm fsXlsXtherm).5965073 (female black asian hispanic nonwhite party)0
simqi


// Mismatch
// Liberal ID / Conservative Source / FS Frame
setx (therm lsXtherm)-.4034927 (lsource)1 (fsframe fsXls fsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// Liberal ID / Conservative Source / PO Frame
setx (therm lsXtherm fsXlsXtherm)-.4034927 (fsframe lsource fsXls)1 (fsXtherm)-.4034927 (female black asian hispanic nonwhite party)0
simqi

// Conservative ID / Liberal Source /FS Frame
setx (therm).5965073 (fsframe lsource fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// Conservative ID / Liberal Source /PO Frame
setx (therm fsXtherm).5965073 (fsframe)1 (lsource fsXls lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// NEITHER Identifiers
// NEITHER ID / Conservative Source / FS Frame
setx (lsource)1 (fsframe therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// NEITHER ID / Conservative Source / PO Frame
setx (fsframe lsource fsXls)1 (therm fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// NEITHER ID / Liberal Source /FS Frame
setx (fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi

// NEITHER ID / Liberal Source /PO Frame
setx (fsframe)1 (lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party)0
simqi


//**2 X 3 Table for DVTOL: Source X Identification (Frame is the Focal IV)
// Reference categories = 0, Key term in the model is FSFRAME (0 = FS, 1 = PO)
// MATCH: Lib Source X Lib ID
ologit dvtol fsframe lsource thermL fsXls fsXthermL lsXthermL fsXlsXthermL female black asian hispanic nonwhite party
// Lib Source X Neither ID
ologit dvtol fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
// Lib Source X Con ID
ologit dvtol fsframe lsource thermH fsXls fsXthermH lsXthermH fsXlsXthermH female black asian hispanic nonwhite party

// Con Source x Lib ID
ologit dvtol fsframe csource thermL fsXcs fsXthermL csXthermL fsXcsXthermL female black asian hispanic nonwhite party
// Con Source X Neither ID
ologit dvtol fsframe csource therm fsXcs fsXtherm csXtherm fsXcsXtherm female black asian hispanic nonwhite party
// MATCH: Con Source X Con ID
ologit dvtol fsframe csource thermH fsXcs fsXthermH csXthermH fsXcsXthermH female black asian hispanic nonwhite party


// 2 x 2 x 2 on DVTOL (with 7-point NES Measure)
ologit dvtol fsframe lsource ideology fsXls fsXideo lsXideo fsXlsXideo female black asian hispanic nonwhite party


// Mediational Analyses on Specific KKK Attitude & General Tolerance Scale
//Value 2 = Free Speech
//Value 3 = Public Order
sgmediation dvrally, mv(value2) iv(fsXlsXtherm) cv(fsframe lsource therm fsXls fsXtherm lsXtherm female black asian hispanic nonwhite party)
sgmediation dvrally, mv(value3) iv(fsXlsXtherm) cv(fsframe lsource therm fsXls fsXtherm lsXtherm female black asian hispanic nonwhite party)

//reg dvrally fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg value2 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg dvrally value2 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party

//reg dvrally fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg value3 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg dvrally value3 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party

//ologit dvtol fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg value2 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//ologit dvtol value2 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party

//ologit dvtol fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//reg value3 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
//ologit dvtol value3 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party

//**2 X 2 Table: Frame X Source (AT MINIMUM LEVELS of Con-Lib Feeling Thermometer--Very Liberal)
// Reference categories = 0, intercepts provide means
// MATCH: FS X Lib Source
//reg value3 fsframe lsource thermL fsXls fsXthermL lsXthermL fsXlsXthermL female black asian hispanic nonwhite party
// FS X Con Source
//reg value3 fsframe csource thermL fsXcs fsXthermL csXthermL fsXcsXthermL female black asian hispanic nonwhite party
// MATCH: PO X Lib Source
//reg value3 poframe lsource thermL poXls poXthermL lsXthermL poXlsXthermL female black asian hispanic nonwhite party
// PO X Con Source
//reg value3 poframe csource thermL poXcs poXthermL csXthermL poXcsXthermL female black asian hispanic nonwhite party

//**2 X 2 Table: Frame X Source (AT MEAN LEVELS of Con-Lib Feeling Thermometer)
// FS X Lib Source
//reg value3 fsframe lsource therm fsXls fsXtherm lsXtherm fsXlsXtherm female black asian hispanic nonwhite party
// FS X Con Source
//reg value3 fsframe csource therm fsXcs fsXtherm csXtherm fsXcsXtherm female black asian hispanic nonwhite party
// PO X Lib
//reg value3 poframe lsource therm poXls poXtherm lsXtherm poXlsXtherm female black asian hispanic nonwhite party
// PO X Con
//reg value3 poframe csource therm poXcs poXtherm csXtherm poXcsXtherm female black asian hispanic nonwhite party

//**2 X 2 Table: Frame X Source (AT MAXIMUM LEVELS of Con-Lib Feeling Thermometer--Very Conservative ID)
// FS X Lib Source:
//reg value3 fsframe lsource thermH fsXls fsXthermH lsXthermH fsXlsXthermH female black asian hispanic nonwhite party
// MATCH: FS X Con Source
//reg value3 fsframe csource thermH fsXcs fsXthermH csXthermH fsXcsXthermH female black asian hispanic nonwhite party
// PO X Lib
//reg value3 poframe lsource thermH poXls poXthermH lsXthermH poXlsXthermH female black asian hispanic nonwhite party
// MATCH: PO X Con
//reg value3 poframe csource thermH poXcs poXthermH csXthermH poXcsXthermH female black asian hispanic nonwhite party

